package com.memorynotfound.quartz;

import org.quartz.*;
import org.quartz.impl.StdSchedulerFactory;
import org.quartz.impl.matchers.KeyMatcher;

import static org.quartz.SimpleScheduleBuilder.*;
import static org.quartz.impl.matchers.EverythingMatcher.allJobs;

public class SimpleTriggerProgram {

    public static void main(String... args) throws SchedulerException {

        // create job
        JobDetail waffleJob = JobBuilder.newJob(BakeWaffles.class)
                .withIdentity("waffleJob", "foodJobGroup")
                .build();

        // create trigger
        TriggerKey triggerKey = new TriggerKey("waffleTrigger", "foodGroup");
        SimpleTrigger trigger = TriggerBuilder.newTrigger()
                .withIdentity(triggerKey)
                .withSchedule(
                        simpleSchedule()
                                .withIntervalInSeconds(60)
                                .repeatForever()
                ).build();

        // schedule it
        Scheduler scheduler = new StdSchedulerFactory().getScheduler();

        // add a listener for every trigger
        scheduler.getListenerManager().addTriggerListener(new GlobalTriggerListener());

        // add a listener only for a certain triggerKey
        scheduler.getListenerManager().addTriggerListener(new GlobalTriggerListener(),
                KeyMatcher.keyEquals(triggerKey));
        scheduler.start();
        scheduler.scheduleJob(waffleJob, trigger);

    }
}
